@@ -12,6 +12,7 @@ import re
 import click
 import urllib.parse
 
+from functools import reduce
 
 from bravado.client import SwaggerClient
 
@@ -105,12 +106,13 @@ class EventLog(peewee.Model):
     queue = peewee.CharField(default="default")
 
     task_key = peewee.CharField(default="unset")
-    state = peewee.CharField(default="unset")
+    task_state = peewee.CharField(default="unset")
 
     worker_id = peewee.CharField()
+    worker_state = peewee.CharField(default="unset")
 
-    timestamp = peewee.DateTimeField()
-    message = peewee.CharField()
+    timestamp = peewee.DateTimeField(default=datetime.datetime.now)
+    message = peewee.CharField(default="unset")
     
     spent_s = peewee.FloatField(default=0)
 
@@ -447,11 +449,26 @@ class Queue:
         instance_for_key['state'] = 'submitted'
         return instance_for_key
 
+    def note_worker_state(self, worker_state):
+        logger.debug("creating new worker state record, worker %s state: %s", self.worker_id, worker_state)
+        r = EventLog.insert(
+                        worker_id = self.worker_id,
+                        worker_state = worker_state,
+                    )\
+                    .execute(database=None)
+        logger.debug("create db operation result %s", r)
+        
+        return r
+    
+    def get_worker_states(self):
+        return [ model_to_dict(r) for r in EventLog.select().where(EventLog.worker_state!="unset").order_by(EventLog.timestamp.desc()).limit(1).execute(database=None) ]
+
     def get(self):
         ""
         if self.current_task is not None:
             raise CurrentTaskUnfinished(self.current_task)
 
+        self.note_worker_state("ready")
     
         r=TaskEntry.update({
                         TaskEntry.state:"running",
@@ -508,9 +525,40 @@ class Queue:
         # compatibility
         return self.clear_event_log()
 
-    def clear_event_log(self):
+    def clear_event_log(self, only_older_than_days: Union[float,None]=None, only_kind: Union[str,None]=None):
         ""
-        print('this is very descructive')
+        if only_older_than_days is None and only_kind is None:
+            logger.warning('this is very desctructive: clearing all event log')
+            return EventLog.delete().execute(database=None)
+
+        f = []
+
+        if only_older_than_days:
+            t0 = datetime.datetime.now() - datetime.timedelta(days=only_older_than_days)
+
+            f.append(EventLog.timestamp < t0)
+            logger.warning('clearing older events: %s', f)
+
+        if only_kind == "task":
+            f.append(EventLog.worker_state == "unset")
+            logger.warning('clearing task events: %s', f)
+        elif only_kind == "worker":
+            f.append(EventLog.worker_state != "unset")
+            logger.warning('clearing worker events: %s', f)
+        else:
+            raise RuntimeError(f"unknown kind {only_kind}; expecting 'task' or 'worker'")
+
+        F = reduce(lambda x,y: x&y, f)
+
+        N = EventLog.delete().where(F).execute(database=None)
+
+        logger.info("clearing: %s", N)
+
+        return N
+    
+    def clear_old_worker_events(self):
+        ""
+        logger.warning('this is very desctructive: clearing event log')
         EventLog.delete().execute(database=None)
 
     def move_task(self, fromk, tok, task, update_entry=False):
@@ -734,7 +782,7 @@ class Queue:
         self.log_task("task failed",self.current_task,"failed")
         
         history=[model_to_dict(en) for en in EventLog.select().where(EventLog.task_key==task.key).order_by(EventLog.id.desc()).execute(database=None)]
-        n_failed = len([he for he in history if he['state'] == "failed"])
+        n_failed = len([he for he in history if he['task_state'] == "failed"])
 
         self.log_task("task failed %i times already"%n_failed,task,"failed")
         if n_failed < n_failed_retries:
@@ -838,7 +886,7 @@ class Queue:
         return EventLog.insert(
                              queue=self.queue,
                              task_key=task_key,
-                             state=state,
+                             task_state=state,
                              worker_id=self.worker_id,
                              timestamp=datetime.datetime.now(),
                              message=message,
