@@ -14,16 +14,39 @@ import urllib.parse as urlparse# type: ignore
 from dqueue.core import Queue, Empty, Task, CurrentTaskUnfinished
 import dqueue.core as core
 import dqueue.typing as types
+from typing import Union
 from dqueue import tools
 
-from bravado.client import SwaggerClient
+from bravado.client import SwaggerClient, RequestsClient
 
 
 
 class QueueProxy(Queue):
     leader = None
     queue = None
-    token = ""
+
+    _token = None
+
+    @property
+    def token(self):
+        if self._token is None:
+            for n, m in [
+                    ("env", lambda: os.environ.get('DDA_TOKEN').strip()),
+                    ("home-dotfile", lambda: open(os.environ.get('HOME')+"/.dda-token").read()),
+                    ("cwd-dotfile", lambda: open(".dda-token").read()),
+                    ]:
+                try:
+                    print("trying", n)
+                    self._token = m()
+                    break
+                except Exception as e:
+                    print(f"method {n} failed: {e}")
+
+            if self._token is None:
+                print(f"all methods to get token failed using default empty")
+                self._token = ""
+
+        return self._token
 
     def __repr__(self):
         return f"[ {self.__class__.__name__}: {self.leader}@{self.queue} ]"
@@ -45,7 +68,18 @@ class QueueProxy(Queue):
     @property
     def client(self):
         if getattr(self, '_client', None) is None:
-            self._client = SwaggerClient.from_url(self.leader.strip("/")+"/apispec_1.json", config={'use_models': False})
+            http_client = RequestsClient()
+
+            http_client.set_api_key(
+                           'dqueue.staging-1-3.odahub.io', "Bearer "+ self.token,
+                             param_name='Authorization', param_in='header'
+                            )
+
+            self._client = SwaggerClient.from_url(
+                        self.leader.strip("/")+"/apispec_1.json",
+                        config={'use_models': False},
+                        http_client=http_client,
+                    )
         return self._client
 
     def find_task_instances(self,task,klist=None):
@@ -65,12 +99,16 @@ class QueueProxy(Queue):
             r['task_dict'] = tools.decode_entry_data(r)
 
         return r
+
+    def clear_event_log(self, only_older_than_days: Union[float,None]=None, only_kind: Union[str,None]=None):
+        return self.client.log.clear(only_older_than_days=only_older_than_days,
+                                     only_kind=only_kind).response().result['N']
     
     def view_log(self, task_key=None, since=0):
         if task_key is None:
             task_key = ""
 
-        return self.client.task.view_log(task_key=task_key,
+        return self.client.log.view(task_key=task_key,
                                          since=since,
                                          token=self.token).response().result
     
